==> pochy-0.2-src.tar.gz: pochy-0.2-src/AccountView.h <==
#if !defined(AFX_ACCOUNTVIEW_H__73A0EFA0_60DE_4734_8A26_F0CD09F58381__INCLUDED_)
#define AFX_ACCOUNTVIEW_H__73A0EFA0_60DE_4734_8A26_F0CD09F58381__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// AccountView.h :
//

/////////////////////////////////////////////////////////////////////////////
// CAccountView tH[ r[

#ifndef __AFXEXT_H__
#include <afxext.h>
#endif

class CAccountView : public CFormView
{
protected:
	CAccountView();           // IɎgpveNg RXgN^B
	DECLARE_DYNCREATE(CAccountView)

// tH[ f[^
public:
	//{{AFX_DATA(CAccountView)
	enum { IDD = IDD_ACCOUNTVIEW };
	CComboBox	m_combo_account;
	//}}AFX_DATA

// Agr[g
public:

// Iy[V
public:
	void SelectAccount(const int& nIndex);
	void SetAccountPopPass(CString account, CString pass);
	void SetSmtpAuthPass(CString account, CString pass);
	CString GetAccountPopPass(CString account);
	CString GetSmtpAuthPass(CString account);
	CString GetFirstAccountName();
	void SetButtonStatus(char *account, int id, BOOL status);
	BOOL GetButtonStatus(char *account, int id);
	void SetFetchStatus(char *account_name, BOOL status);
	BOOL IsFetching(char *account_name);
	int m_index;
	char* GetCurrentAccountName();
	void SetStatusBarText(LPCSTR text,  CString account);
	void SetStatusBarProgress(int current, int upper, CString account);
	CString m_account;
	int GetAccountNum(CString account);
	void CreateNewAccount(const char* name);
	void RenameAccount(const char* org, const char* dst);
	struct ACCOUNT_STRUCT
	{
		BOOL is_fetching;
		BOOL button_fetchmail;
		BOOL button_setting;
		BOOL button_retrieve;
		CString account_name;
		CString status_text;
		CString pop_pass;
		CString smtp_auth_pass;
		int status_pgbar_upper;
		int status_pgbar_current;
	};
	CArray<ACCOUNT_STRUCT, ACCOUNT_STRUCT> m_data;

// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B
	//{{AFX_VIRTUAL(CAccountView)
	public:
	virtual void OnInitialUpdate();
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV T|[g
	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
	//}}AFX_VIRTUAL

// Cve[V
protected:
	virtual ~CAccountView();
#ifdef _DEBUG
	virtual void AssertValid() const;
	virtual void Dump(CDumpContext& dc) const;
#endif

	// ꂽbZ[W }bv֐
	//{{AFX_MSG(CAccountView)
	afx_msg void OnSize(UINT nType, int cx, int cy);
	afx_msg void OnSelchangeAccount();
	afx_msg void OnNextAccount();
	afx_msg void OnPrevAccount();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_ACCOUNTVIEW_H__73A0EFA0_60DE_4734_8A26_F0CD09F58381__INCLUDED_)

==> pochy-0.2.1a-src.tar.gz: pochy-0.2.1a-src/AccountView.h <==
#if !defined(AFX_ACCOUNTVIEW_H__73A0EFA0_60DE_4734_8A26_F0CD09F58381__INCLUDED_)
#define AFX_ACCOUNTVIEW_H__73A0EFA0_60DE_4734_8A26_F0CD09F58381__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// AccountView.h :
//

/////////////////////////////////////////////////////////////////////////////
// CAccountView tH[ r[

#ifndef __AFXEXT_H__
#include <afxext.h>
#endif

class CAccountView : public CFormView
{
protected:
	CAccountView();           // IɎgpveNg RXgN^B
	DECLARE_DYNCREATE(CAccountView)

// tH[ f[^
public:
	//{{AFX_DATA(CAccountView)
	enum { IDD = IDD_ACCOUNTVIEW };
	CComboBox	m_combo_account;
	//}}AFX_DATA

// Agr[g
public:

// Iy[V
public:
	BOOL IsAnyAccountFetching();
	void SelectAccount(const int& nIndex);
	void SetPopPass(LPCTSTR account, LPCTSTR pass);
	void SetSmtpAuthPass(LPCTSTR account, LPCTSTR pass);
	CString GetPopPass(LPCTSTR account);
	CString GetSmtpAuthPass(LPCTSTR account);
	CString GetFirstAccountName();
	void SetButtonStatus(LPCTSTR account, int id, BOOL status);
	BOOL GetButtonStatus(LPCTSTR account, int id);
	void SetFetchStatus(LPCTSTR account_name, BOOL status);
	BOOL IsFetching(LPCTSTR account_name);
	int m_index;
	char* GetCurrentAccountName();
	void SetStatusBarText(LPCTSTR text,  LPCTSTR account);
	void SetStatusBarProgress(int current, int upper, LPCTSTR account);
	CString m_account;
	int GetAccountNum(LPCTSTR account);
	void CreateNewAccount(LPCTSTR name);
	void RenameAccount(LPCTSTR org, LPCTSTR dst);
	struct ACCOUNT_STRUCT
	{
		BOOL is_fetching;
		BOOL button_fetchmail;
		BOOL button_setting;
		BOOL button_retrieve;
		CString account_name;
		CString status_text;
		CString pop_pass;
		CString smtp_auth_pass;
		int status_pgbar_upper;
		int status_pgbar_current;
	};
	CArray<ACCOUNT_STRUCT, ACCOUNT_STRUCT> m_data;

// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B
	//{{AFX_VIRTUAL(CAccountView)
	public:
	virtual void OnInitialUpdate();
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV T|[g
	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
	//}}AFX_VIRTUAL

// Cve[V
protected:
	virtual ~CAccountView();
#ifdef _DEBUG
	virtual void AssertValid() const;
	virtual void Dump(CDumpContext& dc) const;
#endif

	// ꂽbZ[W }bv֐
	//{{AFX_MSG(CAccountView)
	afx_msg void OnSize(UINT nType, int cx, int cy);
	afx_msg void OnSelchangeAccount();
	afx_msg void OnNextAccount();
	afx_msg void OnPrevAccount();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_ACCOUNTVIEW_H__73A0EFA0_60DE_4734_8A26_F0CD09F58381__INCLUDED_)
